<?php
/**
 * webdiary Theme Customizer.
 *
 * @package webdiary
 */


/**
 * Sanitizing the select callback example
 *
 * @since webdiary 1.0.0
 *
 * @see sanitize_key()               https://developer.wordpress.org/reference/functions/sanitize_key/
 * @see $wp_customize->get_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/get_control/
 *
 * @param $input
 * @param $setting
 * @return sanitized output
 *
 */
if ( !function_exists('webdiary_sanitize_select') ) :
    function webdiary_sanitize_select( $input, $setting ) {

        // Ensure input is a slug.
        $input = sanitize_key( $input );

        // Get list of choices from the control associated with the setting.
        $choices = $setting->manager->get_control( $setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
    }
endif;


/**
 * Sanitize checkbox field
 *
 * @since 1.0.0
 */
if ( !function_exists('webdiary_sanitize_checkbox') ) :
        function webdiary_sanitize_checkbox( $checked )
        {
            // Boolean check.
            return ( ( isset( $checked ) && true == $checked ) ? true : false );
        }
    endif;





/**
 *  Default Theme options
 *
 * @since webdiary 1.0.0
 *
 * @param null
 * @return array $webdiary_theme_layout
 *
 */
if ( !function_exists('webdiary_default_theme_options') ) :
    function webdiary_default_theme_options() {

        $default_theme_options = array(
            /*feature section options*/

            'show_fature_slider'       => 1,
            
            'webdiary-feature-cat'     => 0,
            
            'primary_color'            => "#e42549",

            'show_meta_option'         => 1,
           
            'webdiary-footer-copyright'=> esc_html__('Copyright © 2016 - 2017. All Rights Reserved.','webdiary'),

            'read_more_text' => esc_html__('Read More','webdiary')

            
        );

        return apply_filters( 'webdiary_default_theme_options', $default_theme_options );
    }
endif;



/**
 *  Get theme options
 *
 * @since webdiary 1.0.0
 *
 * @param null
 * @return array webdiary_theme_options
 *
 */
if ( !function_exists('webdiary_get_theme_options') ) :
    function webdiary_get_theme_options() {

        $webdiary_default_theme_options = webdiary_default_theme_options();
        

        $webdiary_get_theme_options = get_theme_mod( 'webdiary_theme_options');
        if( is_array( $webdiary_get_theme_options )){
            return array_merge( $webdiary_default_theme_options, $webdiary_get_theme_options );
        }
        else{
            return $webdiary_default_theme_options;
        }

    }
endif;

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function webdiary_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

     /*defaults options*/
    $defaults = webdiary_get_theme_options();


	/*adding sections for footer options*/
    $wp_customize->add_section( 'webdiary-footer-option', array(
        'priority'       => 170,
        'capability'     => 'edit_theme_options',
        'theme_supports' => '',
        'title'          => __( 'Footer Option', 'webdiary' )
    ) );

    /*copyright*/
    $wp_customize->add_setting( 'webdiary_theme_options[webdiary-footer-copyright]', array(
        'capability'        => 'edit_theme_options',
        'default'           =>  $defaults['webdiary-footer-copyright'],
        'sanitize_callback' => 'wp_kses_post'
    ) );
    $wp_customize->add_control( 'webdiary_theme_options[webdiary-footer-copyright]', array(
        'label'     => __( 'Copyright Text', 'webdiary' ),
        'section'   => 'webdiary-footer-option',
        'settings'  => 'webdiary_theme_options[webdiary-footer-copyright]',
        'type'      => 'text',
        'priority'  => 101
    ) );


    /*adding sections for footer options*/
    $wp_customize->add_section( 'webdiary-blog-section-option', array(
        'priority'       => 169,
        'capability'     => 'edit_theme_options',
        'theme_supports' => '',
        'title'          => __( 'Blog Section Option', 'webdiary' )
    ) );



    // Setting Show Metafield
    $wp_customize->add_setting( 'webdiary_theme_options[show_meta_option]',
        array(
            'default'           => $defaults['show_meta_option'],
            'sanitize_callback' => 'webdiary_sanitize_checkbox',
        )
    );

    $wp_customize->add_control( 'webdiary_theme_options[show_meta_option]',
        array(
            'label'             => esc_html__( 'Show Meta Field', 'webdiary' ),
            'section'           => 'webdiary-blog-section-option',
            'type'              => 'checkbox',
            'priority'          => 8,
        )
    );


    // Setting for Readmore Tex
    $wp_customize->add_setting( 'webdiary_theme_options[read_more_text]',
        array(
            'default'           => $defaults['read_more_text'],
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( 'webdiary_theme_options[read_more_text]',
        array(
            'label'             => esc_html__( 'Readmore Text Field', 'webdiary' ),
            'section'           => 'webdiary-blog-section-option',
            'type'              => 'text',
            'priority'          => 8,
        )
    );




    // Setting site primary color.
    $wp_customize->add_setting( 'webdiary_theme_options[primary_color]',
        array(
            'default'           => $defaults['primary_color'],
            'sanitize_callback' => 'sanitize_hex_color',
        )
    );

    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'webdiary_theme_options[primary_color]',
            array(
                'label'       => esc_html__( 'Primary Color', 'webdiary' ),
                'description' => esc_html__( 'Applied to main color of site.', 'webdiary' ),
                'section'     => 'colors',  
            )
        )
    );


   
   
       
    /**
     * Load customizer custom-controls
     */
    require get_template_directory() . '/inc/customizer-inc/custom-controls.php';

    /**
     * Load customizer feature section
     */
    require get_template_directory() . '/inc/customizer-inc/feature-section.php';


}
add_action( 'customize_register', 'webdiary_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function webdiary_customize_preview_js() {
	wp_enqueue_script( 'webdiary_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151216', true );
}
add_action( 'customize_preview_init', 'webdiary_customize_preview_js' );
